@@ -1,8 +1,8 @@
 DATA_DIR = "/gnome/share"
 LIB_DIR = "/gnome/lib"
-VERSION = "2.22.0"
+VERSION = "2.23.2"
 PACKAGE = "gnome-applets"
-PYTHONDIR = "/gnome/lib/python2.4/site-packages"
+PYTHONDIR = "/gnome/lib/python2.5/site-packages"
 GETTEXT_PACKAGE = "gnome-applets-2.0"
 GNOMELOCALEDIR = "/gnome/share/locale"
-GLADEDIR = "/gnome/share/gnome-applets/glade"
+BUILDERDIR = "/gnome/share/gnome-applets/builder"
