@@ -2,20 +2,18 @@ import os, time
 from os.path import *
 import gnomeapplet, gtk, gtk.gdk, gconf, gobject
 from gettext import gettext as _
-import gtk, gtk.glade, gobject, gnomevfs
+import gtk, gobject, gnomevfs
 import csv, os
 
 import invest, invest.about, invest.chart
 
 class QuoteUpdater(gtk.ListStore):
-	__gsignals__ = {
-		"quotes-updated" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
-	}
-	
-	SYMBOL, TICKER_ONLY, BALANCE, BALANCE_PCT, VALUE, VARIATION = range(6)
-	def __init__ (self):
-		gtk.ListStore.__init__ (self, gobject.TYPE_STRING, bool, float, float, float, float)
+	SYMBOL, TICKER_ONLY, BALANCE, BALANCE_PCT, VALUE, VARIATION_PCT = range(6)
+	def __init__ (self, change_icon_callback):
+		gtk.ListStore.__init__ (self, gobject.TYPE_STRING, bool, float, float, float, float, gtk.gdk.Pixbuf)
 		gobject.timeout_add(invest.AUTOREFRESH_TIMEOUT, self.refresh)
+		self.change_icon_callback = change_icon_callback
+		self.refresh()
 		
 	def refresh(self):
 		if len(invest.STOCKS) == 0:
@@ -59,40 +57,75 @@ class QuoteUpdater(gtk.ListStore):
 						result[fields[0]][field[0]] = 0
 				else:
 					result[fields[0]][field] = fields[i]
-					
+			# calculated fields
+			try:
+				result[fields[0]]['variation_pct'] = result[fields[0]]['variation'] / float(result[fields[0]]['trade'] - result[fields[0]]['variation']) * 100
+			except ZeroDivisionError:
+				result[fields[0]]['variation_pct'] = 0
 		return result 
 
 	def populate(self, quotes):
 		self.clear()
 		
-		#current = sum([sum([purchase["amount"]*val["trade"] for purchase in invest.STOCKS[ticker]]) for ticker, val in quotes.items()])
-		#paid = sum([sum([purchase["amount"]*purchase["bought"]+purchase["comission"] for purchase in invest.STOCKS[ticker]]) for ticker in quotes.keys()])
-		#balance = current - paid	
-				
-		#self.append([_("Total"), balance, balance/paid*100, current, 0])
-		
-		for ticker, val in quotes.items():
-			# Check whether the symbol is a syimple quote, or a portfolio value
+		quote_items = quotes.items ()
+		quote_items.sort ()
+
+		simple_quotes_change = 0
+		simple_quotes_count = 0
+		positions_balance = 0
+		positions_count = 0
+
+		for ticker, val in quote_items:
+			pb = None
+			
+			# Check whether the symbol is a simple quote, or a portfolio value
 			is_simple_quote = True
 			for purchase in invest.STOCKS[ticker]:
 				if purchase["amount"] != 0:
 					is_simple_quote = False
 					break
-
+			
 			if is_simple_quote:
-				self.append([ticker, True, 0, 0, val["trade"], val["variation"]])
+				simple_quotes_count += 1
+				row = self.insert(0, [ticker, True, 0, 0, val["trade"], val["variation_pct"], pb])
+				simple_quotes_change += val['variation_pct']
 			else:
+				positions_count += 1
 				current = sum([purchase["amount"]*val["trade"] for purchase in invest.STOCKS[ticker] if purchase["amount"] != 0])
 				paid = sum([purchase["amount"]*purchase["bought"] + purchase["comission"] for purchase in invest.STOCKS[ticker] if purchase["amount"] != 0])
 				balance = current - paid
+				if paid != 0:
+					change = 100*balance/paid
+				else:
+					change = 100 # Not technically correct, but it will look more intuitive than the real result of infinity.
+				row = self.insert(0, [ticker, False, balance, change, val["trade"], val["variation_pct"], pb])
+				positions_balance += balance
 				
-				self.append([ticker, False, balance, balance/paid*100, val["trade"], val["variation"]])
-				
-		self.emit("quotes-updated")
+			invest.chart.FinancialSparklineChartPixbuf(ticker, self.set_pb_callback, row)
+
+		if simple_quotes_count > 0:
+			change = simple_quotes_change/float(simple_quotes_count)
+			if change != 0:
+				self.change_icon_callback(change/abs(change))
+			else:
+				self.change_icon_callback(change)
+		else:
+			self.change_icon_callback(positions_balance/abs(positions_balance))
+
+	def set_pb_callback(self, pb, row):
+		if pb != None:
+			self.set_value(row, 6, pb)
+	
+	# check if we have only simple quotes
+	def simple_quotes_only(self):
+		res = True
+		for entry, value in invest.STOCKS.iteritems():
+			for purchase in value:
+				if purchase["amount"] != 0:
+					res = False
+					break
+		return res
 
 if gtk.pygtk_version < (2,8,0):
 	gobject.type_register(QuoteUpdater)
 
-_updater = QuoteUpdater()
-def get_quotes_updater():
-	return _updater
